@@ -2,7 +2,6 @@
 DataBackendRbind = R6Class("DataBackendRbind", inherit = DataBackend, cloneable = FALSE,
   public = list(
     initialize = function(b1, b2) {
-
       assert_backend(b1)
       assert_backend(b2)
       pk = b1$primary_key
@@ -20,9 +19,8 @@ DataBackendRbind = R6Class("DataBackendRbind", inherit = DataBackend, cloneable
     },
 
     data = function(rows, cols, data_format = self$data_formats[1L]) {
-
       pk = self$primary_key
-      qrows = unique(assert_atomic_vector(rows))
+      qrows = unique(assert_numeric(rows))
       qcols = union(assert_names(cols, type = "unique"), pk)
       assert_choice(data_format, self$data_formats)
 
@@ -34,7 +32,7 @@ DataBackendRbind = R6Class("DataBackendRbind", inherit = DataBackend, cloneable
       }
 
       # duplicate rows / reorder columns
-      data[list(rows), intersect(cols, names(data)), nomatch = 0L, on = pk, with = FALSE]
+      data[list(rows), intersect(cols, names(data)), nomatch = NULL, on = pk, with = FALSE]
     },
 
     head = function(n = 6L) {
