@@ -1,12 +1,15 @@
 #' @title Resample a Learner on a Task
 #'
 #' @description
-#' Runs a resampling (possibly in parallel).
+#' Runs a resampling (possibly in parallel):
+#' Repeatedly apply [Learner] `learner` on a training set of [Task] `task` to train a model,
+#' then use the trained model to predict observations of a test set.
+#' Training and test sets are defined by the [Resampling] `resampling`.
 #'
-#' @param task :: [Task].
-#' @param learner :: [Learner].
-#' @param resampling :: [Resampling].
-#' @param store_models :: `logical(1)`\cr
+#' @param task ([Task]).
+#' @param learner ([Learner]).
+#' @param resampling ([Resampling]).
+#' @param store_models (`logical(1)`)\cr
 #'   Keep the fitted model after the test set has been predicted?
 #'   Set to `TRUE` if you want to further analyse the models or want to
 #'   extract information like variable importance.
@@ -14,10 +17,11 @@
 #'
 #'
 #' @template section_parallelization
+#' @template section_progress_bars
 #' @template section_logging
 #'
 #' @note
-#' The fitted models are discarded after the predictions have been scored in order to reduce memory consumption.
+#' The fitted models are discarded after the predictions have been computed in order to reduce memory consumption.
 #' If you need access to the models for later analysis, set `store_models` to `TRUE`.
 #'
 #' @export
@@ -26,14 +30,14 @@
 #' learner = lrn("classif.rpart")
 #' resampling = rsmp("cv")
 #'
-#' # explicitly instantiate the resampling for this task for reproduciblity
+#' # Explicitly instantiate the resampling for this task for reproduciblity
 #' set.seed(123)
 #' resampling$instantiate(task)
 #'
 #' rr = resample(task, learner, resampling)
 #' print(rr)
 #'
-#' # retrieve performance
+#' # Retrieve performance
 #' rr$score(msr("classif.ce"))
 #' rr$aggregate(msr("classif.ce"))
 #'
@@ -60,17 +64,20 @@ resample = function(task, learner, resampling, store_models = FALSE) {
     instance = instance$instantiate(task)
   }
   n = instance$iters
+  pb = get_progressor(n)
 
   if (use_future()) {
     lg$debug("Running resample() via future with %i iterations", n)
     res = future.apply::future_lapply(seq_len(n), workhorse,
-      task = task, learner = learner, resampling = instance, store_models = store_models, lgr_threshold = lg$threshold,
+      task = task, learner = learner, resampling = instance,
+      store_models = store_models, lgr_threshold = lg$threshold, pb = pb,
       future.globals = FALSE, future.scheduling = structure(TRUE, ordering = "random"),
       future.packages = "mlr3")
   } else {
     lg$debug("Running resample() sequentially with %i iterations", n)
     res = lapply(seq_len(n), workhorse,
-      task = task, learner = learner, resampling = instance, store_models = store_models)
+      task = task, learner = learner, resampling = instance,
+      store_models = store_models, pb = pb)
   }
 
   res = map_dtr(res, reassemble, learner = learner)
