@@ -6,25 +6,25 @@ test_that("DataBackendDataTable construction", {
   expect_backend(b)
   expect_iris_backend(b)
 
-  data = iris
-  data$id = sprintf("r%02i", 1:150)
+  i = 1:30
+  data = iris[i, ]
+  data$id = i
   b = as_data_backend(data, primary_key = "id")
   expect_backend(b)
-  expect_character(b$rownames, len = 150, any.missing = FALSE, unique = TRUE, pattern = "^r[0-9]+$")
+  expect_set_equal(b$rownames, i)
 
-  rownames(data) = data$id
+  rownames(data) = sprintf("rn_%i", data$id)
   data$id = NULL
-  b = as_data_backend(data)
+  b = as_data_backend(data, keep_rownames = TRUE)
   expect_backend(b)
-  expect_character(b$rownames, len = 150, any.missing = FALSE, unique = TRUE, pattern = "^r[0-9]+$")
+  expect_set_equal(b$data(i, "..rownames")[[1]], sprintf("rn_%i", i))
 
-  data$Petal.Length[21:50] = NA
+  data$Petal.Length[21:30] = NA
   b = as_data_backend(data)
   x = b$missings(b$rownames, c("Petal.Width", "Petal.Length"))
-  expect_equal(x, set_names(c(0L, 30L), c("Petal.Width", "Petal.Length")))
+  expect_equal(x, set_names(c(0L, 10L), c("Petal.Width", "Petal.Length")))
 })
 
-
 test_that("DataBackendDataTable with 0 rows", {
   b = as_data_backend(iris[integer(), ])
   expect_backend(b)
