@@ -1,6 +1,6 @@
 context("mlr_resampling_custom")
 
 test_that("custom has duplicated ids", {
-  r = mlr_resamplings$get("custom")
+  r = rsmp("custom")
   expect_identical(r$duplicated_ids, TRUE)
 })
